
# THIS FILE IS GENERATED FROM pyedflib SETUP.PY
short_version = '0.1.30'
version = '0.1.30'
full_version = '0.1.30'
git_revision = 'c03e8fed91c462dae40605816aba41fe76025891'
release = True

if not release:
    version = full_version
